pub struct Fingerprint {
pub(crate) nodes: Vec<Point>,
pub(crate) edges: Vec<(Point, Point, Cost)>,
}Expand description
A lattice in a form two routers can be compared by. See
ClosedRouter::fingerprint.
Fields
nodes: Vec<Point>edges: Vec<(Point, Point, Cost)>Implementations
Sourceimpl Fingerprint
impl Fingerprint
Sourcepub fn difference(&self, other: &Self) -> String
pub fn difference(&self, other: &Self) -> String
How the two differ, for a test that needs to say more than “not equal”.